@@ -98,7 +98,7 @@ def print_used_pins():
     os.system('pinout')
     print (USED_PINS)
   
-def t_up(speed = SPEED, t_time = TIME):
+def move_forward(speed = SPEED, t_time = TIME):
 
     L_Motor.ChangeDutyCycle(speed)
     GPIO.output(AIN2,False)#AIN2
@@ -111,11 +111,11 @@ def t_up(speed = SPEED, t_time = TIME):
 
     #near_verge = fall_detection()
     #if (near_verge):
-    #    t_down(SPEED, 0.5)
+    #    move_backward(SPEED, 0.5)
     #    # SOS or buzz
     #    destroy('fall_detection')
         
-def t_stop(t_time = TIME):
+def stop(t_time = TIME):
 
     L_Motor.ChangeDutyCycle(0)
     GPIO.output(AIN2,False)#AIN2
@@ -126,7 +126,7 @@ def t_stop(t_time = TIME):
     GPIO.output(BIN1,False) #BIN1
     time.sleep(t_time)
         
-def t_down(speed = SPEED,t_time = TIME):
+def move_backward(speed = SPEED,t_time = TIME):
     L_Motor.ChangeDutyCycle(speed)
     GPIO.output(AIN2,True)#AIN2
     GPIO.output(AIN1,False) #AIN1
@@ -136,7 +136,7 @@ def t_down(speed = SPEED,t_time = TIME):
     GPIO.output(BIN1,False) #BIN1
     time.sleep(t_time)
 
-def t_left(speed = SPEED,t_time = TIME):
+def turn_left(speed = SPEED,t_time = TIME):
     L_Motor.ChangeDutyCycle(speed)
     GPIO.output(AIN2,True)#AIN2
     GPIO.output(AIN1,False) #AIN1
@@ -146,7 +146,7 @@ def t_left(speed = SPEED,t_time = TIME):
     GPIO.output(BIN1,True) #BIN1
     time.sleep(t_time)
 
-def t_right(speed = SPEED,t_time = TIME):
+def turn_right(speed = SPEED,t_time = TIME):
     L_Motor.ChangeDutyCycle(speed)
     GPIO.output(AIN2,False)#AIN2
     GPIO.output(AIN1,True) #AIN1
@@ -160,19 +160,19 @@ def keyscan():
 
     val = GPIO.input(BtnPin)
     while GPIO.input(BtnPin) == False:  # wait for press       
-        # val = GPIO.input(BtnPin)
-        print('front detection: ', front_detection())
-        # print('back detection: ', back_detection())
+        led.test_led(R_val = 40, G_val = 0, B_val = 0)
+        led.test_led(R_val = 0, G_val = 70, B_val =0)
+        led.test_led(R_val = 0, G_val = 0, B_val = 90)
 
     time.sleep(0.1) # after start, set green light on and red off
 
+    return
+
     # another press will stop the program
     GPIO.setup(BtnPin, GPIO.IN, pull_up_down=GPIO.PUD_UP)    # Set BtnPin's mode is input, and pull up to high level(3.3V)
     GPIO.add_event_detect(BtnPin, GPIO.BOTH,
                 callback= stop_vehicle,
                 bouncetime=200) # TypeError: xxx() takes 0 positional arguments but 1 was given
-
-    return
             
 def setup():
 
@@ -319,7 +319,7 @@ def loop():
     while True:
 
         while not RUNNING:
-            t_stop(1) # after stopping acc, the vehicle will enter step mode.
+            stop(1) # after stopping acc, the vehicle will enter step mode.
 
         if True:
             near_verge = False # the current fall detection is too sensative, turn it off
@@ -329,42 +329,42 @@ def loop():
             # c_back_left, c_back_right = False, False
             if (c_left and not c_right) or (c_back_left and not c_back_right):
                 print('C L > R', c_left, c_right, c_back_left, c_back_right)
-                t_right(SPEED,0)
+                turn_right(SPEED,0)
             elif (not c_left and c_right) or (not c_back_left and c_back_right):
                 print('C L < R', c_left, c_right, c_back_left, c_back_right)
-                t_left(SPEED,0)
+                turn_left(SPEED,0)
             elif c_left and c_right:
                 print('C LR', c_left, c_right, c_back_left, c_back_right)
-                t_stop(0.1)
-                t_down(SPEED, 0.5)
+                stop(0.1)
+                move_backward(SPEED, 0.5)
             elif c_back_left and c_back_right:
                 print('C BLR', c_left, c_right, c_back_left, c_back_right)
-                t_stop(0.1)
-                t_up(SPEED, 0.3)
+                stop(0.1)
+                move_forward(SPEED, 0.3)
 
         distance_F = front_detection()
 
         if distance_F < 40: # or near_verge or c_left or c_right or c_back_left or c_back_right:
-            t_stop(0.2)
-            t_down(SPEED,0.2)
-            t_stop(0.2)
+            stop(0.2)
+            move_backward(SPEED,0.2)
+            stop(0.2)
 
             distance_L = left_detection()
             distance_R = right_detection()
             
             if (distance_L < 40) == True and (distance_R < 40) == True:
                 print('US LR < 40', distance_L, distance_R)
-                t_left(SPEED,1)
+                turn_left(SPEED,1)
             elif (distance_L > distance_R) == True:
                 print('US L > R', distance_L, distance_R)
-                t_left(SPEED,0.3)
-                t_stop(0.1)
+                turn_left(SPEED,0.3)
+                stop(0.1)
             else:
                 print('US L < R', distance_L, distance_R)
-                t_right(SPEED,0.3)
-                t_stop(0.1)
+                turn_right(SPEED,0.3)
+                stop(0.1)
         else:
-            t_up(SPEED,0)
+            move_forward(SPEED,0)
         
         
         ################### The tracking band function #################
@@ -373,21 +373,21 @@ def loop():
             _, SL, _, SR = fall_detection()
             if SL == False and SR == False:
                 print ("Up")
-                t_up(50,0)
+                move_forward(50,0)
             elif SL == True and SR ==False:
                 print ("Left")
-                t_left(50,0)
+                turn_left(50,0)
             elif SL==False and SR ==True:
                 print ("Right")
-                t_right(50,0)
+                turn_right(50,0)
             else:
-                t_stop(0)
+                stop(0)
 
 def stop_vehicle(ch):
     print('Stop Vehicle by ' , ch)
     # L_Motor.stop()
     # R_Motor.stop()
-    t_stop(2)
+    stop(2)
 
 def destroy(ch):
     print('Destroy by' , ch)
