@@ -1,41 +1,55 @@
+import os
+import time
 from datetime import datetime
-from random import choices
+from pathlib import Path
+import cv2
+from PIL import Image, ImageTk, ImageDraw,ImageFont
+from threading import *
+
 import ttkbootstrap as ttk
 from ttkbootstrap.style import Bootstyle
 from tkinter.filedialog import askdirectory
 from ttkbootstrap.dialogs import Messagebox
 from ttkbootstrap.constants import *
 from tkinter.scrolledtext import ScrolledText
-from pathlib import Path
+from ttkbootstrap.toast import ToastNotification
+
+'''
+About binding keys to functions, refer to: 
+https://tkinterexamples.com/events/keyboard/
+'''
 
 if __package__:
     from . import led, acc, servo, joystick
     from . import passive_buzzer as pbz
     from . import PCF8591 as adc
     from . import ds18b20 as temperature
+    from .setting_frame import SettingFrame
 else:
     import led, acc, servo, joystick
     import passive_buzzer as pbz
     import PCF8591 as adc
     import ds18b20 as temperature
+    from setting_frame import SettingFrame
 # import sys
 # sys.path.insert(0, './vehicle')
 # import vehicle.Adafruit_PWM_Servo_Driver as servo_drv
-from threading import *
-from PIL import Image, ImageTk
-import cv2
-from datetime import datetime
-from random import choice
-from ttkbootstrap.toast import ToastNotification
 
-cap = cv2.VideoCapture(0)
-INTERVAL = 200 # ms
+
+CAMERA_ID = 0
+cap = cv2.VideoCapture(CAMERA_ID)
+INTERVAL = 100 # ms
+LIVEVIEW_SIZE = (240,180)
+SAVE_DIR = 'ocam_captures/'
+
 DEFAULT_WINSIZE = '500x400'
 ENABLE_FULLSCREEN = False
+TREEVIEW_ROW_HEIGHT = 21
 
 TEST_LED = '1'
 TEST_PASSIVE_BUZZER = '3'
 TEST_SERVO = '4'
+TEST_RA = '8'
 TEST_JOYSTICK = '2'
 TEST_ADC = '5'
 TEST_LASER = '6' # Laser pin is connected to LED Blue Pin
@@ -48,7 +62,29 @@ class MainGui(ttk.Frame):
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.pack(fill=BOTH, expand=YES)
+        self.pack(fill=BOTH, expand=YES)        
+
+        led.RUNNING = False
+        # led.setup() # called inside acc.setup()
+        temperature.setup()
+        pbz.RUNNING = False
+        # pbz.setup() # Share with RGB LED Bpin. called inside acc.setup()
+        # servo.setup()  # called inside acc.setup()
+        joystick.RUNNING = False
+        adc.RUNNING = False
+        acc.RUNNINGwadw = False
+        acc.setup()
+        
+        self.distance_F = 1000
+        self.distance_L = 1000
+        self.distance_R = 1000
+
+        '''
+        # start a background distance measurement thread
+        self.distance_monitor = Thread(target = self.measure_distance)
+        self.distance_monitor.setDaemon(True)
+        self.distance_monitor.start()
+        '''
 
         image_files = {
             'properties-dark': 'icons8_settings_24px.png',
@@ -61,9 +97,11 @@ class MainGui(ttk.Frame):
             'stop-dark': 'icons8_stop_24px.png',
             'stop-light': 'icons8_stop_24px_1.png',
             'opened-folder': 'icons8_opened_folder_24px.png',
-            'logo': 'backup.png'
+            'logo': 'backup.png',
+            # 'splash': 'splash.png', # support png, but dont support jpg
         }
 
+
         self.photoimages = []
         for key, val in image_files.items():
             _path = PATH / val
@@ -142,16 +180,24 @@ class MainGui(ttk.Frame):
             title='Camera', 
             bootstyle=SECONDARY)
 
+        ## Camera liveview
+        self.media = ttk.Label(bus_frm, image='logo', style='bg.TLabel') # , image=self.demo_media)
+        self.media.bind('<Double-1>', self.change_liveview_size)
+        self.media.grid(row=0, column=0, columnspan=3, sticky=N+S+E+W) # .pack(fill=BOTH, expand=YES)
+        self.liveview_size=LIVEVIEW_SIZE
+        self.UpdateImage(INTERVAL)
+
         ## camera pan tilt control
         _func = lambda: servo.pan_tilt_left()
         add_btn = ttk.Button(
             master=bus_frm, 
-            text='left', 
+            text='LEFT', 
             compound=LEFT,
             command=_func, 
             bootstyle=LINK
         )
-        add_btn.grid(row=5, column=0, rowspan=2, sticky=W)
+        add_btn.grid(row=5, column=0, rowspan=1, sticky=W)
+        self.master.bind('<Left>',lambda x: servo.pan_tilt_left())
 
         _func = lambda: servo.pan_tilt_up()
         add_btn = ttk.Button(
@@ -161,7 +207,8 @@ class MainGui(ttk.Frame):
             command=_func, 
             bootstyle=LINK
         )
-        add_btn.grid(row=5, column=1, rowspan=1, sticky=N)
+        add_btn.grid(row=4, column=1, rowspan=1, sticky=N)
+        self.master.bind('<Up>',lambda x: servo.pan_tilt_up())
 
         _func = lambda: servo.pan_tilt_down()
         add_btn = ttk.Button(
@@ -172,6 +219,7 @@ class MainGui(ttk.Frame):
             bootstyle=LINK
         )
         add_btn.grid(row=6, column=1, rowspan=1, sticky=S)
+        self.master.bind('<Down>',lambda x: servo.pan_tilt_down())
 
         _func = lambda: servo.pan_tilt_right()
         add_btn = ttk.Button(
@@ -181,12 +229,22 @@ class MainGui(ttk.Frame):
             command=_func, 
             bootstyle=LINK
         )
-        add_btn.grid(row=5, column=2, rowspan=2, sticky=E)
+        add_btn.grid(row=5, column=2, rowspan=1, sticky=E)
+        self.master.bind('<Right>',lambda x: servo.pan_tilt_right())
+        
+        
+        _func = lambda: servo.reset_tilt()
+        add_btn = ttk.Button(
+            master=bus_frm, 
+            text='RESET', 
+            compound=LEFT,
+            command=_func, 
+            bootstyle=LINK
+        )
+        add_btn.grid(row=5, column=1, rowspan=1, sticky=E)
+        self.master.bind('<r>',lambda x: servo.reset_tilt())
 
-        ## Camera liveview
-        self.media = ttk.Label(bus_frm, image='logo', style='bg.TLabel') # , image=self.demo_media)
-        self.media.grid(row=7, column=0, columnspan=3, sticky=N+S+E+W) # .pack(fill=BOTH, expand=YES)
-        self.UpdateImage(INTERVAL)
+        self.master.bind('<Return>', lambda x: self.capture_image())
 
         ################## VEHICLE ######################
 
@@ -203,37 +261,40 @@ class MainGui(ttk.Frame):
 
         
         ## vehicle control
-        _func = lambda: acc.t_left()
+        _func = lambda: acc.turn_left()
         add_btn = ttk.Button(
             master=v_frm, 
-            text='left', 
+            text='LEFT', 
             compound=LEFT,
             command=_func, 
             bootstyle=LINK
         )
-        add_btn.grid(row=5, column=0, rowspan=2, sticky=W)
+        add_btn.grid(row=5, column=0, rowspan=1, sticky=W)
+        self.master.bind('<a>',lambda x: acc.turn_left() )
 
-        _func = lambda: acc.t_up()
+        _func = lambda: acc.move_forward()
         add_btn = ttk.Button(
             master=v_frm, 
-            text='UP', 
+            text='FORWARD', 
             compound=TOP,
             command=_func, 
             bootstyle=LINK
         )
-        add_btn.grid(row=5, column=1, rowspan=1, sticky=N)
+        add_btn.grid(row=4, column=1, rowspan=1, sticky=N)
+        self.master.bind('<w>', lambda x: acc.move_forward() )
 
-        _func = lambda: acc.t_down()
+        _func = lambda: acc.move_backward()
         add_btn = ttk.Button(
             master=v_frm, 
-            text='DOWN', 
+            text='BACKWARD', 
             compound=BOTTOM,
             command=_func, 
             bootstyle=LINK
         )
         add_btn.grid(row=6, column=1, rowspan=1, sticky=S)
+        self.master.bind('<x>',lambda x: acc.move_backward() )
 
-        _func = lambda: acc.t_right()
+        _func = lambda: acc.turn_right()
         add_btn = ttk.Button(
             master=v_frm, 
             text='RIGHT', 
@@ -241,7 +302,19 @@ class MainGui(ttk.Frame):
             command=_func, 
             bootstyle=LINK
         )
-        add_btn.grid(row=5, column=2, rowspan=2, sticky=E)
+        add_btn.grid(row=5, column=2, rowspan=1, sticky=E)
+        self.master.bind('<d>',lambda x: acc.turn_right())
+
+        _func = lambda: acc.stop()
+        add_btn = ttk.Button(
+            master=v_frm, 
+            text='STOP', 
+            compound=LEFT,
+            command=_func, 
+            bootstyle=LINK
+        )
+        add_btn.grid(row=5, column=1, rowspan=1, sticky=E)
+        self.master.bind('<s>',lambda x: acc.stop())
 
         ## section separator
         sep = ttk.Separator(v_frm, bootstyle=SECONDARY)
@@ -260,18 +333,115 @@ class MainGui(ttk.Frame):
             bootstyle=LINK
         )
         btn.pack(side=LEFT, fill=X, expand=YES) #.grid(row=0, column=0, columnspan=1, sticky=W)
+        self.master.bind('<space>',lambda x: self.stop())
 
-        _func = lambda: Messagebox.ok(message='Changing properties')
         btn = ttk.Button(
             master=h_container, 
             text='Config', 
             image='properties-dark', 
             compound=LEFT,
-            command=_func, 
+            command=self.open_settings, 
             bootstyle=LINK
         )
         btn.pack(side=LEFT, fill=X, expand=YES) #.grid(row=0, column=1, columnspan=1, sticky=W)
 
+
+        ################## RA ######################
+
+        v_cf = CollapsingFrame(left_panel)
+        v_cf.pack(fill=X, pady=1)
+
+        ## container
+        v_frm = ttk.Frame(v_cf, padding=5)
+        v_frm.columnconfigure(1, weight=1)
+        v_cf.add(
+            child=v_frm, 
+            title='robotic arm', 
+            bootstyle=SECONDARY)
+
+        _func = lambda: servo.ra_left()
+        add_btn = ttk.Button(
+            master=v_frm, 
+            text='LEFT', 
+            compound=LEFT,
+            command=_func, 
+            bootstyle=LINK
+        )
+        add_btn.grid(row=5, column=0, rowspan=2, sticky=W)
+        self.master.bind('<j>',lambda x: servo.ra_left() )
+
+        _func = lambda: servo.ra_f()
+        add_btn = ttk.Button(
+            master=v_frm, 
+            text='FORWARD', 
+            compound=TOP,
+            command=_func, 
+            bootstyle=LINK
+        )
+        add_btn.grid(row=5, column=1, rowspan=1, sticky=N)
+        self.master.bind('<i>', lambda x: servo.ra_f() )
+
+        _func = lambda: servo.ra_b()
+        add_btn = ttk.Button(
+            master=v_frm, 
+            text='BACKWARD', 
+            compound=BOTTOM,
+            command=_func, 
+            bootstyle=LINK
+        )
+        add_btn.grid(row=6, column=1, rowspan=1, sticky=S)
+        self.master.bind('<comma>',lambda x: servo.ra_b() )
+
+        _func = lambda: servo.ra_right()
+        add_btn = ttk.Button(
+            master=v_frm, 
+            text='RIGHT', 
+            compound=LEFT,
+            command=_func, 
+            bootstyle=LINK
+        )
+        add_btn.grid(row=5, column=2, rowspan=2, sticky=E)
+        self.master.bind('<l>',lambda x: servo.ra_right())
+
+        ## section separator
+        sep = ttk.Separator(v_frm, bootstyle=SECONDARY)
+        sep.grid(row=7, column=0, columnspan=3, pady=10, sticky=EW)
+
+
+        _func = lambda: servo.ra_up()
+        add_btn = ttk.Button(
+            master=v_frm, 
+            text='UP', 
+            compound=LEFT,
+            command=_func, 
+            bootstyle=LINK
+        )
+        add_btn.grid(row=8, column=0, rowspan=1, sticky=E)
+        self.master.bind('<u>',lambda x: servo.ra_up())
+
+        _func = lambda: servo.ra_down()
+        add_btn = ttk.Button(
+            master=v_frm, 
+            text='DOWN', 
+            compound=LEFT,
+            command=_func, 
+            bootstyle=LINK
+        )
+        add_btn.grid(row=8, column=1, rowspan=1, sticky=E)
+        self.master.bind('<m>',lambda x: servo.ra_down())
+
+        _func = lambda: servo.ra_clamp()
+        add_btn = ttk.Button(
+            master=v_frm, 
+            text='CLAMP', 
+            compound=LEFT,
+            command=_func, 
+            bootstyle=LINK
+        )
+        add_btn.grid(row=8, column=2, rowspan=1, sticky=E)
+        self.master.bind('<period>',lambda x: servo.ra_clamp())
+        self.master.bind('<o>',lambda x: servo.ra_clamp())
+
         ############## STATUS Panel ################
         # status (collapsible)
         status_cf = CollapsingFrame(left_panel)
@@ -308,9 +478,37 @@ class MainGui(ttk.Frame):
         lbl.grid(row=2, column=1, sticky=EW, padx=5, pady=2)
         self.setvar('cpu_info', str(psutil.cpu_freq().max) + 'MHz x ' + str(psutil.cpu_count(logical=False)) )
 
+
+        lbl = ttk.Label(status_frm, text='Speed:')
+        lbl.grid(row=3, column=0, sticky=W, pady=2)
+        scale = ttk.Scale(
+            master=status_frm,
+            orient=HORIZONTAL,
+            from_=30,
+            to=60,
+            value=acc.SPEED,
+            command=self.set_speed,
+            bootstyle=INFO # SUCCESS
+        )
+        scale.grid(row=3, column=1, columnspan=2, sticky=EW, padx=5, pady=2)
+
+
+        ttk.Label(status_frm, text='FPS:').grid(row=4, column=0, sticky=W, pady=2)
+        scale2 = ttk.Scale(
+            master=status_frm,
+            orient=HORIZONTAL,
+            from_=200,
+            to=10,
+            value=INTERVAL, # default 200
+            command=self.set_fps,
+            bootstyle=INFO # SUCCESS
+        )
+        scale2.grid(row=4, column=1, columnspan=2, sticky=EW, padx=5, pady=2)
+
+
         ## section separator
         sep = ttk.Separator(status_frm, bootstyle=SECONDARY)
-        sep.grid(row=3, column=0, columnspan=3, pady=10, sticky=EW)
+        sep.grid(row=5, column=0, columnspan=3, pady=10, sticky=EW)
 
         ## progress message
         lbl = ttk.Label(
@@ -318,7 +516,7 @@ class MainGui(ttk.Frame):
             textvariable='prog-message', 
             font='Helvetica 10 bold'
         )
-        lbl.grid(row=4, column=0, columnspan=3, sticky=W)
+        lbl.grid(row=6, column=0, columnspan=3, sticky=W)
         self.setvar('prog-message', 'Running...')
 
         ## progress bar
@@ -327,22 +525,22 @@ class MainGui(ttk.Frame):
             variable='prog-value', 
             bootstyle=SUCCESS
         )
-        pb.grid(row=5, column=0, columnspan=3, sticky=EW, pady=(10, 5))
+        pb.grid(row=7, column=0, columnspan=3, sticky=EW, pady=(10, 5))
         self.setvar('prog-value', 71)
 
         ## time started
         lbl = ttk.Label(status_frm, textvariable='prog-time-started')
-        lbl.grid(row=6, column=0, columnspan=3, sticky=EW, pady=2)
+        lbl.grid(row=8, column=0, columnspan=3, sticky=EW, pady=2)
         self.setvar('prog-time-started', 'Started at: 14.06.2021 19:34:56')
 
         ## time elapsed
         lbl = ttk.Label(status_frm, textvariable='prog-time-elapsed')
-        lbl.grid(row=7, column=0, columnspan=3, sticky=EW, pady=2)
+        lbl.grid(row=9, column=0, columnspan=3, sticky=EW, pady=2)
         self.setvar('prog-time-elapsed', 'Elapsed: 1 sec')
 
         ## time remaining
         lbl = ttk.Label(status_frm, textvariable='prog-time-left')
-        lbl.grid(row=8, column=0, columnspan=3, sticky=EW, pady=2)
+        lbl.grid(row=10, column=0, columnspan=3, sticky=EW, pady=2)
         self.setvar('prog-time-left', 'Left: 0 sec')
 
         ## section separator
@@ -364,7 +562,7 @@ class MainGui(ttk.Frame):
         
 
         ## Treeview
-        tv = ttk.Treeview(right_panel, show='headings', height=9)
+        tv = ttk.Treeview(right_panel, show='headings', height=10)
         tv.configure(columns=(
             'Device', 'GPIO', 'Description'
         ))
@@ -376,7 +574,8 @@ class MainGui(ttk.Frame):
         for col in tv['columns']:
             tv.heading(col, text=col.title(), anchor=W)
         
-        tv.pack(fill=X, pady=1)    
+        tv.pack(fill=X, pady=1)
+        ttk.Style().configure('Treeview', rowheight = TREEVIEW_ROW_HEIGHT, font=('', round(TREEVIEW_ROW_HEIGHT * 0.5)))
 
         ## scrolling text output
         scroll_cf = CollapsingFrame(right_panel)
@@ -427,6 +626,13 @@ I2C devices:
 0x70 - 
 
 To check a full list of I2C addresses, go to https://i2cdevices.org/addresses
+
+servo channels:
+0 - super-sonic
+1,2 - tilt
+3 - back super-sonic
+4,5,6,7 - robotic arm
+
         '''       
 
         self.setvar('scroll-message', _value)
@@ -438,32 +644,14 @@ To check a full list of I2C addresses, go to https://i2cdevices.org/addresses
 
         ## treeview
         tv.insert('', END, TEST_LED, values = ('LED', '5,6,17', 'LED调试'))
-        led.RUNNING = False
-        # led.setup() # called inside acc.setup()
-
-        tv.insert('', END, TEST_LASER, values = ('Laser', '17', 'Laser'))
-        
+        tv.insert('', END, TEST_LASER, values = ('Laser', '17', 'Laser'))       
         tv.insert('', END, TEST_W1, values = ('Temperature', '1-Wire', 'ds18b20'))
-        temperature.setup()
-
         tv.insert('', END, TEST_PASSIVE_BUZZER, values = ('Passive Buzzer', '17', '声音'))
-        pbz.RUNNING = False
-        # pbz.setup() # Share with RGB LED Bpin. called inside acc.setup()
-
-        tv.insert('', END, TEST_SERVO, values = ('Servos', 'I2C 0x40', '舵机'))
-        # servo.setup()  # called inside acc.setup()
-
+        tv.insert('', END, TEST_SERVO, values = ('Servos', 'I2C 0x40 0~7', '舵机'))
+        tv.insert('', END, TEST_RA, values = ('Robotic Arm', 'I2C 0x40 4~7', '机械臂'))
         tv.insert('', END, TEST_JOYSTICK, values = ('Joystick', 'I2C 0x48 A0A1A2', 'Joystick Controller'))
-        joystick.RUNNING = False
-        
         tv.insert('', END, TEST_ADC, values = ('ADC', 'I2C 0x48', 'PCF8591'))
-        adc.RUNNING = False
-
         tv.insert('', END, TEST_ACC, values = ('Vehicle', '11', '自适应巡航ACC'))
-        acc.RUNNING = False
-        acc.setup()
-
-        # tv.insert('', END, 2, values = ('Buzzer', '', 'RGB LED调试'))
         
         tv.bind('<Double-1>', self.on_tree_dbclicked)
         # tv.selection_set(1)
@@ -478,6 +666,7 @@ To check a full list of I2C addresses, go to https://i2cdevices.org/addresses
                 led.RUNNING = True
                 led.pwm_B.stop()
                 led.pwm_B.start(0)
+
                 self.test_led = Thread(target = led.loop)
                 self.test_led.setDaemon(True)
                 self.test_led.start()        
@@ -494,6 +683,11 @@ To check a full list of I2C addresses, go to https://i2cdevices.org/addresses
             self.test_servo.setDaemon(True)
             self.test_servo.start()
 
+        elif item == TEST_RA: 
+            self.test_ra = Thread(target = servo.test_ra)
+            self.test_ra.setDaemon(True)
+            self.test_ra.start()
+
         elif item == TEST_LASER: 
             self.test_laser = Thread(target = led.sos)
             self.test_laser.setDaemon(True)
@@ -520,18 +714,34 @@ To check a full list of I2C addresses, go to https://i2cdevices.org/addresses
         elif item == TEST_ACC: 
             if acc.RUNNING == False:
                 acc.RUNNING = True
+                self.change_liveview_size()
                 self.test_acc = Thread(target = acc.loop)
                 self.test_acc.setDaemon(True)
                 self.test_acc.start()
 
+    def open_settings(self):
+
+        dapp= ttk.Toplevel(app)
+        dapp.title("参数设置")
+        SettingFrame(dapp)
+
+    def set_speed(self,x):
+        acc.SPEED = round( float(str(x)) ) # int(self.scale.get())
+
+    # x actually means 1/FPS
+    def set_fps(self,x):
+        INTERVAL = round( float(str(x)) ) # int(self.scale.get())
+
     def stop(self):
+        print('stop')
+
         led.RUNNING=False
         pbz.RUNNING=False
         acc.RUNNING=False
         joystick.RUNNING=False
         adc.RUNNING=False
 
-        acc.t_stop()
+        acc.stop()        
 
     def get_directory(self):
         """Open dialogue to get directory and update variable"""
@@ -548,18 +758,74 @@ To check a full list of I2C addresses, go to https://i2cdevices.org/addresses
         # reschedule to run again in 1 second
         self.after(delay, self.UpdateImage, INTERVAL) # frame rate
 
+    def measure_distance(self, front_only = True):
+
+        # while(True): # cannot do it in a thread
+
+        # inside this loop, we judge distance to avoid collision
+        self.distance_F = round(acc.front_detection())
+        
+        if not front_only:
+            self.distance_L = round(acc.left_detection())
+            self.distance_R = round(acc.right_detection())
+            print(self.distance_F, self.distance_L, self.distance_R)
+
+        if self.distance_F < 20:
+            acc.stop(0.2)
+            acc.move_backward(t_time = 0.2)
+            acc.stop(0.2)        
+
     def get_image(self):
 
         cv2image= cv2.cvtColor(cap.read()[1],cv2.COLOR_BGR2RGB)
         img = Image.fromarray(cv2image)        
 
+        if acc.RUNNING == False:
+
+            front_only = True
+            self.measure_distance(front_only=front_only) # update distances
+            if front_only:
+                s = "Distance : " + str(self.distance_F)
+            else:
+                s = "Distances : " + str(self.distance_L) + ', ' + str(self.distance_F) + ',' + str(self.distance_R)
+            draw = ImageDraw.Draw(img)
+            ft = ImageFont.truetype('FreeMono.ttf', 25)
+            draw.text((10, 10), 
+            s, 
+            font = ft,
+            fill =(255, 255, 255))
+            # draw.text((10, 10), "Distances : " + str(round(distance,1)), font=ft, fill =(255, 255, 255))
+
         # Resize the image using resize() method
         # print(self.winfo_width() , self.winfo_height())
-        resize_image = img.resize((240,180)) # img.resize((self.media.winfo_width() , max(self.media.winfo_height() - 50, 1) ))
+        resize_image = img.resize(self.liveview_size) 
         imgtk = ImageTk.PhotoImage(resize_image)
 
         return img, imgtk
 
+    def capture_image(self):
+
+        if not os.path.exists(SAVE_DIR):
+            os.makedirs(SAVE_DIR)
+
+        fn = SAVE_DIR + datetime.now().strftime("%Y%m%d%H%M%S") + '.jpg'
+        self.pil_image.save( fn )
+        # messagebox.showinfo("Message","Hey There! I hope you are doing well.")
+        
+        toast = ToastNotification(
+            title="图片保存成果",
+            message="保存路径为" + fn,
+            duration=1000,
+        )
+        toast.show_toast()
+
+    def change_liveview_size(self, event = None):
+        print(event)
+        if (self.liveview_size == LIVEVIEW_SIZE):
+            self.liveview_size = self.master.winfo_width() , max(self.master.winfo_height() - 50, 1)
+        else:
+            self.liveview_size = LIVEVIEW_SIZE # (240,180)
+
 class CollapsingFrame(ttk.Frame):
     """A collapsible frame widget that opens and closes with a click."""
 
@@ -641,12 +907,15 @@ class CollapsingFrame(ttk.Frame):
             child.grid()
             child.btn.configure(image=self.images[0])
 
-
 if __name__ == '__main__':
     
+    # splash_root = ttk.Window()
+    # splash_label = ttk.Label(splash_root, image='logo')
+    # splash_label.pack()
+    # splash_root.after(3000, lambda : splash_root.destroy())
+
     app = ttk.Window("Raspi Control Panel")
     app.geometry(DEFAULT_WINSIZE)
     app.attributes('-fullscreen', ENABLE_FULLSCREEN)
-
     MainGui(app)
     app.mainloop()
